@@ -6,6 +6,8 @@ use Carp;
 
 1;
 
+sub tag { (shift)->[-1] }
+
 sub recommended { croak "no recommendation" }
 
 sub new {
@@ -32,7 +34,11 @@ sub set_days {
         undef,  # the sum of the data
         undef,  # the the last numerator
         undef,  # the WMA
+
+        undef,  # tag must be last
     );
+
+    $this->[-1] = "WMA($arg)";
 }
 
 sub insert {
@@ -68,7 +74,7 @@ sub insert {
 sub query {
     my $this = shift;
 
-    return $this->[-1];
+    return $this->[5];
 }
 
 __END__
